Developer Interface
===================

Forms and Fields
----------------

.. module:: flask_wtf

.. autoclass:: FlaskForm
    :members:

.. autoclass:: Form(...)

.. autoclass:: RecaptchaField

.. autoclass:: Recaptcha

.. autoclass:: RecaptchaWidget

.. module:: flask_wtf.file

.. autoclass:: FileField(...)

.. autoclass:: FileAllowed

.. autoclass:: FileRequired

CSRF Protection
---------------

.. module:: flask_wtf.csrf

.. autoclass:: CSRFProtect
    :members:

.. autoclass:: CsrfProtect(...)

.. autoclass:: CSRFError
    :members:

.. autofunction:: generate_csrf

.. autofunction:: validate_csrf
